//*****************************************************************************
// Description     : Definition of commands for controlling device
// Target Device   : APN504X
// Target Platform : Linux, C
// Date            : August 2017
// Version         : 1.0
//*****************************************************************************
#ifndef __COMMAND__
#define __COMMAND__


//******************* command address  ********************
// command
#define DEVICE_COMMAND_MOD   (0xb4000010)    // measurement mode
#define DEVICE_COMMAND_AQS   (0xb4000014)    // start/stop
#define DEVICE_COMMAND_MTM   (0xb4000016)    // measurement time
#define DEVICE_COMMAND_CLR   (0xb4000040)    // clear data
#define DEVICE_COMMAND_RQH   (0xb400004a)    // request histogram
#define DEVICE_COMMAND_DAC   (0xb400007a)    // DAC monitor

#define DEVICE_COMMAND_ACG   (0xb4000200)    // analog coarse gain
#define DEVICE_COMMAND_ADG   (0xb4000202)    // ADC gain
#define DEVICE_COMMAND_SFR   (0xb4000208)    // slow filter rise time
#define DEVICE_COMMAND_SFP   (0xb400020a)    // slow filter peaking time
#define DEVICE_COMMAND_FPZ   (0xb400020c)    // fast filter pole zero
#define DEVICE_COMMAND_SPZ   (0xb400020e)    // slow filter pole zero
#define DEVICE_COMMAND_FTH   (0xb4000210)    // fast trigger threshold
#define DEVICE_COMMAND_STH   (0xb4000216)    // slow filter threshold
#define DEVICE_COMMAND_POL   (0xb400021a)    // polarity
#define DEVICE_COMMAND_RFL   (0xb4000238)    // filter reset
#define DEVICE_COMMAND_DCG   (0xb400023a)    // digital coarse gain
#define DEVICE_COMMAND_DFG   (0xb400023c)    // digital fine gain
#define DEVICE_COMMAND_FGD   (0xb4000258)    // analog fine gain
#define DEVICE_COMMAND_PZD   (0xb4000256)    // analog polezero

// status
#define DEVICE_STATUS_RTM    (0xb400001c)    // real time
#define DEVICE_STATUS_ICR    (0xb400022c)    // input count rate(cps)
#define DEVICE_STATUS_TCR    (0xb4000230)    // throughput count rate(cps)


//******************* parameter ********************
// measurement mode
#define DEVICE_PARAM_MOD_HIST   (0)     // histogram
#define DEVICE_PARAM_MOD_WAVE   (1)     // wave

// measurement start/stop
#define DEVICE_PARAM_AQS_STOP   (0)     // stop
#define DEVICE_PARAM_AQS_START  (1)     // start

// DAC monitor
#define DEVICE_PARAM_DAC_CH1_PRE    (0)     // CH1 pre amp
#define DEVICE_PARAM_DAC_CH1_FAST   (1)     // CH1 fast
#define DEVICE_PARAM_DAC_CH1_SLOW   (2)     // CH1 slow
#define DEVICE_PARAM_DAC_CH1_CFD    (3)     // CH1 CFD

// analog coarse gain
#define DEVICE_PARAM_ACG_x5     (1)     // x5
#define DEVICE_PARAM_ACG_x10    (2)     // x10
#define DEVICE_PARAM_ACG_x20    (3)     // x20

// ADC gain
#define DEVICE_PARAM_ADG_4096   (1)     // 4096
#define DEVICE_PARAM_ADG_2048   (2)     // 2048
#define DEVICE_PARAM_ADG_1024   (3)     // 1024
#define DEVICE_PARAM_ADG_512    (4)     //  512
#define DEVICE_PARAM_ADG_256    (5)     //  256

// polarity
#define DEVICE_PARAM_POL_POS    (0)     // positive
#define DEVICE_PARAM_POL_NEG    (1)     // negative

// digital coarse gain
#define DEVICE_PARAM_DCG_x1     (0)     // x1
#define DEVICE_PARAM_DCG_x2     (1)     // x2
#define DEVICE_PARAM_DCG_x4     (2)     // x4
#define DEVICE_PARAM_DCG_x8     (3)     // x8
#define DEVICE_PARAM_DCG_x16    (4)     // x16
#define DEVICE_PARAM_DCG_x32    (5)     // x32
#define DEVICE_PARAM_DCG_x64    (6)     // x64
#define DEVICE_PARAM_DCG_x128   (7)     // x128


#endif // __COMMAND__
